# TestPointSelectModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**test_suite_ids** | **[str], none_type** |  | [optional] 
**work_item_global_ids** | **[int], none_type** |  | [optional] 
**statuses** | [**[TestPointStatus], none_type**](TestPointStatus.md) |  | [optional] 
**priorities** | [**[WorkItemPriorityModel], none_type**](WorkItemPriorityModel.md) |  | [optional] 
**is_automated** | **bool, none_type** |  | [optional] 
**name** | **str, none_type** |  | [optional] 
**configuration_ids** | **[str], none_type** |  | [optional] 
**tester_ids** | **[str], none_type** |  | [optional] 
**duration** | [**Int64RangeSelectorModel**](Int64RangeSelectorModel.md) |  | [optional] 
**section_ids** | **[str], none_type** |  | [optional] 
**created** | [**DateTimeRangeSelectorModel**](DateTimeRangeSelectorModel.md) |  | [optional] 
**created_by_ids** | **[str], none_type** |  | [optional] 
**modified** | [**DateTimeRangeSelectorModel**](DateTimeRangeSelectorModel.md) |  | [optional] 
**modified_by_ids** | **[str], none_type** |  | [optional] 
**tags** | **[str], none_type** |  | [optional] 
**attributes** | **{str: ([str],)}, none_type** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


